```
lura is a collection of helper modules.

  attrs: dicts which treat attributes as keys
 crypto: syntactic sugar for cryptography.fernet
    fmt: a standard api for dealing with json, yaml, etc.
   hash: syntactic sugar for hashlib
  hooks: primitive event dispatcher
     io: syntactic sugar for io activities
   iter: iterator helpers
    log: logging configurator and syntactic sugar
 random: random number helpers
  shell: helpers for working with the shell
   sudo: popen()-like api for spawning processes with sudo
testing: helpers for writing tests
threads: syntactic sugar for threads
   time: time-related helpers
   tmpl: a standard api for dealing with templating systems
 trace_: call tracing
  utils: a module for homeless objects
```
